# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.update_test_run_examples import UpdateTestRunExamples

class TestUpdateTestRunExamples(unittest.TestCase):
    """UpdateTestRunExamples unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTestRunExamples:
        """Test UpdateTestRunExamples
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTestRunExamples`
        """
        model = UpdateTestRunExamples()
        if include_optional:
            return UpdateTestRunExamples(
                id = '1379',
                rank = 1,
                values = ["value1","value2"],
                status = 'TODO',
                status_description = 'Description of the status',
                duration = '12960',
                backgrounds = [
                    openapi_client.models.test_example_step_bean.TestExampleStepBean(
                        id = 1, 
                        rank = 1, 
                        type = 'type', 
                        keyword = 'Example Keyword', 
                        name = 'Example Name', 
                        duration = '14226', 
                        log_error = '', 
                        status = 'PASS', )
                    ],
                hooks = [
                    openapi_client.models.test_example_step_bean.TestExampleStepBean(
                        id = 1, 
                        rank = 1, 
                        type = 'type', 
                        keyword = 'Example Keyword', 
                        name = 'Example Name', 
                        duration = '14226', 
                        log_error = '', 
                        status = 'PASS', )
                    ],
                steps = [
                    openapi_client.models.test_example_step_bean.TestExampleStepBean(
                        id = 1, 
                        rank = 1, 
                        type = 'type', 
                        keyword = 'Example Keyword', 
                        name = 'Example Name', 
                        duration = '14226', 
                        log_error = '', 
                        status = 'PASS', )
                    ]
            )
        else:
            return UpdateTestRunExamples(
        )
        """

    def testUpdateTestRunExamples(self):
        """Test UpdateTestRunExamples"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
