# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_definition_one_of import TestDefinitionOneOf

class TestTestDefinitionOneOf(unittest.TestCase):
    """TestDefinitionOneOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestDefinitionOneOf:
        """Test TestDefinitionOneOf
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestDefinitionOneOf`
        """
        model = TestDefinitionOneOf()
        if include_optional:
            return TestDefinitionOneOf(
                steps = [
                    openapi_client.models.test_definition_one_of_steps_inner.Test_definition_oneOf_steps_inner(
                        id = 56, 
                        index = 56, 
                        step = openapi_client.models.test_definition_one_of_steps_inner_step.Test_definition_oneOf_steps_inner_step(
                            raw = '', 
                            rendered = '', ), 
                        data = openapi_client.models.test_definition_one_of_steps_inner_step.Test_definition_oneOf_steps_inner_step(
                            raw = '', 
                            rendered = '', ), 
                        result = , 
                        attachements = [
                            ''
                            ], )
                    ]
            )
        else:
            return TestDefinitionOneOf(
        )
        """

    def testTestDefinitionOneOf(self):
        """Test TestDefinitionOneOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
