# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.tests_api import TestsApi


class TestTestsApi(unittest.TestCase):
    """TestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TestsApi()

    def tearDown(self) -> None:
        pass

    def test_settings_teststatuses_get(self) -> None:
        """Test case for settings_teststatuses_get

        """
        pass

    def test_test_get(self) -> None:
        """Test case for test_get

        """
        pass

    def test_test_key_preconditions_get(self) -> None:
        """Test case for test_key_preconditions_get

        """
        pass

    def test_test_key_testexecutions_get(self) -> None:
        """Test case for test_key_testexecutions_get

        """
        pass

    def test_test_key_testplans_get(self) -> None:
        """Test case for test_key_testplans_get

        """
        pass

    def test_test_key_testruns_get(self) -> None:
        """Test case for test_key_testruns_get

        """
        pass

    def test_test_key_testsets_get(self) -> None:
        """Test case for test_key_testsets_get

        """
        pass


if __name__ == '__main__':
    unittest.main()
