# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.v10_api_test_get200_response_inner_definition_one_of_steps_inner_step import V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep

class TestV10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep(unittest.TestCase):
    """V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep:
        """Test V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep`
        """
        model = V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep()
        if include_optional:
            return V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep(
                raw = '',
                rendered = ''
            )
        else:
            return V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep(
        )
        """

    def testV10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep(self):
        """Test V10ApiTestGet200ResponseInnerDefinitionOneOfStepsInnerStep"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
