# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.model10_api_test_get200_response_inner import Model10ApiTestGet200ResponseInner

class TestModel10ApiTestGet200ResponseInner(unittest.TestCase):
    """Model10ApiTestGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Model10ApiTestGet200ResponseInner:
        """Test Model10ApiTestGet200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Model10ApiTestGet200ResponseInner`
        """
        model = Model10ApiTestGet200ResponseInner()
        if include_optional:
            return Model10ApiTestGet200ResponseInner(
                key = '',
                var_self = '',
                reporter = '',
                precondition = [
                    openapi_client.models._1_0_api_test_get_200_response_inner_precondition_inner._1_0_api_test_get_200_response_inner_precondition_inner(
                        precondition_key = '', 
                        self = '', 
                        reporter = '', 
                        assignee = '', 
                        type = '', 
                        condition = '', )
                    ],
                type = '',
                status = '',
                definition = None
            )
        else:
            return Model10ApiTestGet200ResponseInner(
        )
        """

    def testModel10ApiTestGet200ResponseInner(self):
        """Test Model10ApiTestGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
