# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_response_tests_inner import TestResponseTestsInner

class TestTestResponseTestsInner(unittest.TestCase):
    """TestResponseTestsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestResponseTestsInner:
        """Test TestResponseTestsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestResponseTestsInner`
        """
        model = TestResponseTestsInner()
        if include_optional:
            return TestResponseTestsInner(
                key = '',
                var_self = '',
                reporter = '',
                precondition = {
                    'key' : null
                    },
                type = '',
                status = '',
                definition = ''
            )
        else:
            return TestResponseTestsInner(
        )
        """

    def testTestResponseTestsInner(self):
        """Test TestResponseTestsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
