# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.rest_api_success_response_test_issues import RestApiSuccessResponseTestIssues

class TestRestApiSuccessResponseTestIssues(unittest.TestCase):
    """RestApiSuccessResponseTestIssues unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RestApiSuccessResponseTestIssues:
        """Test RestApiSuccessResponseTestIssues
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RestApiSuccessResponseTestIssues`
        """
        model = RestApiSuccessResponseTestIssues()
        if include_optional:
            return RestApiSuccessResponseTestIssues(
                success = [
                    openapi_client.models.rest_api_success_response_test_issues_success_inner.RestApiSuccessResponse_testIssues_success_inner(
                        id = '', 
                        key = '', 
                        self = '', 
                        test_version_id = 56, )
                    ],
                error = [
                    openapi_client.models.rest_api_success_response_test_issues_error_inner.RestApiSuccessResponse_testIssues_error_inner(
                        test_definition = '', 
                        messages = [
                            ''
                            ], )
                    ]
            )
        else:
            return RestApiSuccessResponseTestIssues(
        )
        """

    def testRestApiSuccessResponseTestIssues(self):
        """Test RestApiSuccessResponseTestIssues"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
