# coding: utf-8

# flake8: noqa
"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openapi_client.models.called_step import CalledStep
from openapi_client.models.create_step import CreateStep
from openapi_client.models.create_step_request_body import CreateStepRequestBody
from openapi_client.models.create_step_response import CreateStepResponse
from openapi_client.models.create_step_response_step import CreateStepResponseStep
from openapi_client.models.custom_field_meta_information import CustomFieldMetaInformation
from openapi_client.models.data_field import DataField
from openapi_client.models.dataset_parameter import DatasetParameter
from openapi_client.models.defects import Defects
from openapi_client.models.error import Error
from openapi_client.models.field_value import FieldValue
from openapi_client.models.file import File
from openapi_client.models.file_response import FileResponse
from openapi_client.models.folder_rest_bean import FolderRestBean
from openapi_client.models.get_testruns200_response_inner import GetTestruns200ResponseInner
from openapi_client.models.get_testruns200_response_inner_evidences_inner import GetTestruns200ResponseInnerEvidencesInner
from openapi_client.models.get_testruns200_response_inner_steps_inner import GetTestruns200ResponseInnerStepsInner
from openapi_client.models.iteration_step_information import IterationStepInformation
from openapi_client.models.model10_api_testrepository_project_key_folders_folder_id_get200_response import Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response
from openapi_client.models.model10_api_testrun_id_customfield_custom_field_id_put_request import Model10ApiTestrunIdCustomfieldCustomFieldIdPutRequest
from openapi_client.models.model10_api_testrun_id_iteration_iteration_id_step_step_result_id_status_get200_response import Model10ApiTestrunIdIterationIterationIdStepStepResultIdStatusGet200Response
from openapi_client.models.option_custom_field_meta_information import OptionCustomFieldMetaInformation
from openapi_client.models.option_field import OptionField
from openapi_client.models.option_value import OptionValue
from openapi_client.models.project_test_run_cf_meta_information_inner import ProjectTestRunCFMetaInformationInner
from openapi_client.models.project_test_step_cf_meta_information_inner import ProjectTestStepCFMetaInformationInner
from openapi_client.models.rest_api_success_response import RestApiSuccessResponse
from openapi_client.models.rest_api_success_response_test_exec_issue import RestApiSuccessResponseTestExecIssue
from openapi_client.models.rest_api_success_response_test_issues import RestApiSuccessResponseTestIssues
from openapi_client.models.rest_api_success_response_test_issues_error_inner import RestApiSuccessResponseTestIssuesErrorInner
from openapi_client.models.rest_api_success_response_test_issues_success_inner import RestApiSuccessResponseTestIssuesSuccessInner
from openapi_client.models.rest_api_success_response_test_run_warnings_inner import RestApiSuccessResponseTestRunWarningsInner
from openapi_client.models.step import Step
from openapi_client.models.step_custom_field_meta_information import StepCustomFieldMetaInformation
from openapi_client.models.step_fields_value import StepFieldsValue
from openapi_client.models.step_option_custom_field_meta_information import StepOptionCustomFieldMetaInformation
from openapi_client.models.step_response import StepResponse
from openapi_client.models.step_result import StepResult
from openapi_client.models.step_result_actual_result import StepResultActualResult
from openapi_client.models.step_result_comment import StepResultComment
from openapi_client.models.step_results_response import StepResultsResponse
from openapi_client.models.test_example_step_bean import TestExampleStepBean
from openapi_client.models.test_response_inner import TestResponseInner
from openapi_client.models.test_response_inner_definition import TestResponseInnerDefinition
from openapi_client.models.test_response_inner_definition_one_of import TestResponseInnerDefinitionOneOf
from openapi_client.models.test_response_inner_definition_one_of_steps_inner import TestResponseInnerDefinitionOneOfStepsInner
from openapi_client.models.test_response_inner_definition_one_of_steps_inner_step import TestResponseInnerDefinitionOneOfStepsInnerStep
from openapi_client.models.test_response_inner_precondition_inner import TestResponseInnerPreconditionInner
from openapi_client.models.test_run_custom_field_multi import TestRunCustomFieldMulti
from openapi_client.models.test_run_custom_field_response import TestRunCustomFieldResponse
from openapi_client.models.test_run_custom_field_single import TestRunCustomFieldSingle
from openapi_client.models.test_run_example import TestRunExample
from openapi_client.models.test_run_iteration_information import TestRunIterationInformation
from openapi_client.models.test_run_iteration_status_information import TestRunIterationStatusInformation
from openapi_client.models.test_run_response import TestRunResponse
from openapi_client.models.test_run_response_custom_fields_inner import TestRunResponseCustomFieldsInner
from openapi_client.models.test_step_result_evidence_input import TestStepResultEvidenceInput
from openapi_client.models.test_steps_response import TestStepsResponse
from openapi_client.models.test_steps_response_steps_inner import TestStepsResponseStepsInner
from openapi_client.models.update_iteration import UpdateIteration
from openapi_client.models.update_iteration_response import UpdateIterationResponse
from openapi_client.models.update_iteration_status import UpdateIterationStatus
from openapi_client.models.update_step import UpdateStep
from openapi_client.models.update_step_attachments import UpdateStepAttachments
from openapi_client.models.update_step_request_body import UpdateStepRequestBody
from openapi_client.models.update_step_result import UpdateStepResult
from openapi_client.models.update_step_result_defects import UpdateStepResultDefects
from openapi_client.models.update_step_result_evidences import UpdateStepResultEvidences
from openapi_client.models.update_tr_custom_field_value_multi import UpdateTRCustomFieldValueMulti
from openapi_client.models.update_tr_custom_field_value_single import UpdateTRCustomFieldValueSingle
from openapi_client.models.update_test_run import UpdateTestRun
from openapi_client.models.update_test_run_custom_field_multi import UpdateTestRunCustomFieldMulti
from openapi_client.models.update_test_run_custom_field_single import UpdateTestRunCustomFieldSingle
from openapi_client.models.update_test_run_custom_fields_inner import UpdateTestRunCustomFieldsInner
from openapi_client.models.update_test_run_evidences import UpdateTestRunEvidences
from openapi_client.models.update_test_run_examples import UpdateTestRunExamples
from openapi_client.models.update_test_run_response import UpdateTestRunResponse
from openapi_client.models.version import Version
from openapi_client.models.wiki_field import WikiField
from openapi_client.models.wiki_value import WikiValue
from openapi_client.models.xray_json_import_execution import XrayJsonImportExecution
from openapi_client.models.xray_json_import_execution_info import XrayJsonImportExecutionInfo
from openapi_client.models.xray_json_import_execution_tests_inner import XrayJsonImportExecutionTestsInner
from openapi_client.models.xray_json_import_execution_tests_inner_evidences_inner import XrayJsonImportExecutionTestsInnerEvidencesInner
from openapi_client.models.xray_json_import_execution_tests_inner_results_inner import XrayJsonImportExecutionTestsInnerResultsInner
from openapi_client.models.xray_json_import_execution_tests_inner_steps_inner import XrayJsonImportExecutionTestsInnerStepsInner
from openapi_client.models.xray_json_import_execution_tests_inner_test_info import XrayJsonImportExecutionTestsInnerTestInfo
from openapi_client.models.xray_license_status import XrayLicenseStatus
