# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_run_custom_field_single import TestRunCustomFieldSingle

class TestTestRunCustomFieldSingle(unittest.TestCase):
    """TestRunCustomFieldSingle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestRunCustomFieldSingle:
        """Test TestRunCustomFieldSingle
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestRunCustomFieldSingle`
        """
        model = TestRunCustomFieldSingle()
        if include_optional:
            return TestRunCustomFieldSingle(
                id = 28,
                name = 'Toogle Custom Field',
                value = 'true'
            )
        else:
            return TestRunCustomFieldSingle(
        )
        """

    def testTestRunCustomFieldSingle(self):
        """Test TestRunCustomFieldSingle"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
