# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.update_step import UpdateStep

class TestUpdateStep(unittest.TestCase):
    """UpdateStep unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateStep:
        """Test UpdateStep
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateStep`
        """
        model = UpdateStep()
        if include_optional:
            return UpdateStep(
                fields = {"Action":"Step Action","Date":"02/Feb/2020","Toggle":"true","SingleSelectList":"Selected Value","MultiSelectList":["Option A","Option B"]},
                attachments = openapi_client.models.update_step_attachments.UpdateStep_attachments(
                    add = [
                        openapi_client.models.file.File(
                            data = 'gsddfgdsfg...(base64)', 
                            filename = 'example.txt', 
                            content_type = 'plain/text', )
                        ], 
                    remove = [1234,4546], )
            )
        else:
            return UpdateStep(
        )
        """

    def testUpdateStep(self):
        """Test UpdateStep"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
