# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.update_test_run_response import UpdateTestRunResponse

class TestUpdateTestRunResponse(unittest.TestCase):
    """UpdateTestRunResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTestRunResponse:
        """Test UpdateTestRunResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTestRunResponse`
        """
        model = UpdateTestRunResponse()
        if include_optional:
            return UpdateTestRunResponse(
                id = 1004725,
                evidence_ids = [
                    56
                    ],
                warnings = [
                    '["Test example with id 1379 does not belong to test run with id 1004725."]'
                    ],
                step_results = [
                    openapi_client.models.step_results_response.StepResultsResponse(
                        id = 813743, 
                        evidence_ids = [
                            56
                            ], 
                        warnings = [
                            '["No attachment with id 123 was found."]'
                            ], )
                    ]
            )
        else:
            return UpdateTestRunResponse(
        )
        """

    def testUpdateTestRunResponse(self):
        """Test UpdateTestRunResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
