# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.xray_json_import_execution import XrayJsonImportExecution

class TestXrayJsonImportExecution(unittest.TestCase):
    """XrayJsonImportExecution unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> XrayJsonImportExecution:
        """Test XrayJsonImportExecution
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `XrayJsonImportExecution`
        """
        model = XrayJsonImportExecution()
        if include_optional:
            return XrayJsonImportExecution(
                test_execution_key = '',
                info = openapi_client.models.xray_json_import_execution_info.XrayJsonImportExecution_info(
                    project = '', 
                    summary = '', 
                    description = '', 
                    user = '', 
                    version = '', 
                    revision = '', 
                    start_date = '', 
                    finish_date = '', ),
                tests = [
                    openapi_client.models.xray_json_import_execution_tests_inner.XrayJsonImportExecution_tests_inner(
                        comment = '', 
                        finish = '', 
                        start = '', 
                        status = '', 
                        test_version = '', 
                        custom_fields = [
                            null
                            ], 
                        test_info = openapi_client.models.xray_json_import_execution_tests_inner_test_info.XrayJsonImportExecution_tests_inner_testInfo(
                            test_type = '', 
                            project_key = '', 
                            summary = '', 
                            scenario_type = '', 
                            scenario = '', 
                            definition = '', 
                            requirement_keys = '', 
                            test_version_id = 56, ), 
                        test_key = '', 
                        executed_by = '', 
                        evidences = [
                            openapi_client.models.xray_json_import_execution_tests_inner_evidences_inner.XrayJsonImportExecution_tests_inner_evidences_inner(
                                data = '', 
                                filename = '', 
                                content_type = '', )
                            ], 
                        results = [
                            openapi_client.models.xray_json_import_execution_tests_inner_results_inner.XrayJsonImportExecution_tests_inner_results_inner(
                                name = '', 
                                duration = 56, 
                                log = '', 
                                status = '', 
                                examples = [
                                    ''
                                    ], )
                            ], 
                        examples = [
                            ''
                            ], 
                        steps = [
                            openapi_client.models.xray_json_import_execution_tests_inner_steps_inner.XrayJsonImportExecution_tests_inner_steps_inner(
                                status = '', 
                                comment = '', 
                                actual_result = '', )
                            ], )
                    ]
            )
        else:
            return XrayJsonImportExecution(
        )
        """

    def testXrayJsonImportExecution(self):
        """Test XrayJsonImportExecution"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
