# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.test_step_result_evidence_input import TestStepResultEvidenceInput

class TestTestStepResultEvidenceInput(unittest.TestCase):
    """TestStepResultEvidenceInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestStepResultEvidenceInput:
        """Test TestStepResultEvidenceInput
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestStepResultEvidenceInput`
        """
        model = TestStepResultEvidenceInput()
        if include_optional:
            return TestStepResultEvidenceInput(
                data = 'iVBORw0KGgoAAAANSUhEUgAABkIAAAO9CAYAAADezXv6AAAAAXNSR0IArs4c6QAA(...base64 file enconding)',
                filename = 'image21.jpg',
                content_type = 'image/jpeg'
            )
        else:
            return TestStepResultEvidenceInput(
        )
        """

    def testTestStepResultEvidenceInput(self):
        """Test TestStepResultEvidenceInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
