# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.test_plan_tests_api import TestPlanTestsApi


class TestTestPlanTestsApi(unittest.TestCase):
    """TestPlanTestsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TestPlanTestsApi()

    def tearDown(self) -> None:
        pass

    def test_testplan_test_plan_key_test_get(self) -> None:
        """Test case for testplan_test_plan_key_test_get

        """
        pass

    def test_testplan_test_plan_key_test_post(self) -> None:
        """Test case for testplan_test_plan_key_test_post

        """
        pass

    def test_testplan_test_plan_key_test_test_key_delete(self) -> None:
        """Test case for testplan_test_plan_key_test_test_key_delete

        """
        pass


if __name__ == '__main__':
    unittest.main()
