# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.get_testruns200_response_inner import GetTestruns200ResponseInner

class TestGetTestruns200ResponseInner(unittest.TestCase):
    """GetTestruns200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetTestruns200ResponseInner:
        """Test GetTestruns200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetTestruns200ResponseInner`
        """
        model = GetTestruns200ResponseInner()
        if include_optional:
            return GetTestruns200ResponseInner(
                id = 56,
                test_exec_key = '',
                test_key = '',
                status = '',
                type = '',
                test_version = '',
                start = '',
                defects = [
                    ''
                    ],
                evidences = [
                    openapi_client.models.get_testruns_200_response_inner_evidences_inner.get_testruns_200_response_inner_evidences_inner(
                        filename = '', 
                        content_type = '', 
                        data = '', )
                    ],
                steps = [
                    openapi_client.models.get_testruns_200_response_inner_steps_inner.get_testruns_200_response_inner_steps_inner(
                        status = '', 
                        comment = '', 
                        defects = [
                            ''
                            ], 
                        evidences = [
                            openapi_client.models.get_testruns_200_response_inner_evidences_inner.get_testruns_200_response_inner_evidences_inner(
                                filename = '', 
                                content_type = '', 
                                data = '', )
                            ], 
                        actual_result = '', )
                    ],
                parameters = [
                    openapi_client.models.dataset_parameter.DatasetParameter(
                        name = '', 
                        value = '', )
                    ],
                assignee = '',
                test_environments = [
                    ''
                    ],
                comment = ''
            )
        else:
            return GetTestruns200ResponseInner(
        )
        """

    def testGetTestruns200ResponseInner(self):
        """Test GetTestruns200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
