# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.models.model10_api_testrepository_project_key_folders_folder_id_get200_response import Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response

class TestModel10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(unittest.TestCase):
    """Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response:
        """Test Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response`
        """
        model = Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response()
        if include_optional:
            return Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(
                id = 1001,
                rank = 1,
                name = 'Unit Tests',
                test_count = 2,
                total_test_count = 12,
                test_repository_path = '/v4.3.2/AutomatedTests',
                folder_ids = [1002, 1003]
            )
        else:
            return Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(
        )
        """

    def testModel10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response(self):
        """Test Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
