# coding: utf-8

"""
    Xray REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from openapi_client.api.test_run_api import TestRunApi


class TestTestRunApi(unittest.TestCase):
    """TestRunApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TestRunApi()

    def tearDown(self) -> None:
        pass

    def test_get_testruns(self) -> None:
        """Test case for get_testruns

        
        """
        pass

    def test_testrun_get(self) -> None:
        """Test case for testrun_get

        """
        pass

    def test_testrun_id_customfield_custom_field_id_get(self) -> None:
        """Test case for testrun_id_customfield_custom_field_id_get

        """
        pass

    def test_testrun_id_customfield_custom_field_id_put(self) -> None:
        """Test case for testrun_id_customfield_custom_field_id_put

        """
        pass

    def test_testrun_id_get(self) -> None:
        """Test case for testrun_id_get

        """
        pass

    def test_testrun_id_iteration_iteration_id_get(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_get

        """
        pass

    def test_testrun_id_iteration_iteration_id_put(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_put

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_get(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_get

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_attachment_attachment_id_delete(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_attachment_attachment_id_delete

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_attachment_delete(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_attachment_delete

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_attachment_get(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_attachment_get

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_attachment_post(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_attachment_post

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_get(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_get

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_put(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_put

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_status_get(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_status_get

        """
        pass

    def test_testrun_id_iteration_iteration_id_step_step_result_id_status_put(self) -> None:
        """Test case for testrun_id_iteration_iteration_id_step_step_result_id_status_put

        """
        pass

    def test_testrun_id_put(self) -> None:
        """Test case for testrun_id_put

        """
        pass


if __name__ == '__main__':
    unittest.main()
